##
##  dyncall.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2022 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         dyncall
Summary:      Dynamic Foreign Function Call Library
URL:          http://dyncall.org/
Vendor:       Daniel Adler, Tassilo Philipp
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Compiler
License:      MIT
Version:      1.4
Release:      20221207

#   list of sources
Source0:      http://dyncall.org/r%{version}/dyncall-%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc
PreReq:       OpenPKG, openpkg >= 20160101

%description
    The dyncall library encapsulates architecture-, OS- and
    compiler-specific function call semantics in a virtual "bind
    argument parameters from left to right and then call" interface
    allowing programmers to call C functions in a completely dynamic
    manner. In other words, instead of calling a function directly,
    the dyncall library provides a mechanism to push the function
    parameters manually and to issue the call afterwards. This means,
    that a program can determine at runtime what function to call, and
    what parameters to pass to it. The library is written in C and
    assembly and provides a very simple C interface to program against.
    The library comes in very handy to power flexible message systems,
    dynamic function call dispatch mechanisms, closure implementations
    or even to bridge different programming languages. When it comes
    to language bindings, the dyncall library provides a clean and
    portable C interface to dynamically issue calls to foreign code
    using small call kernels written in assembly. Instead of providing
    code for every bridged function call, which unnecessarily results in
    code bloat, only a couple of instructions are used to invoke every
    possible call.

%track
    prog dyncall = {
        version   = %{version}
        url       = http://www.dyncall.org/download
        regex     = dyncall-(__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    ./configure \
        --prefix=%{l_prefix}
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install PREFIX=$RPM_BUILD_ROOT%{l_prefix}
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

